==> cilint-0.0.10.tgz: package/lib/engine.js <==
'use strict';

var _createClass = function () { function defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } } return function (Constructor, protoProps, staticProps) { if (protoProps) defineProperties(Constructor.prototype, protoProps); if (staticProps) defineProperties(Constructor, staticProps); return Constructor; }; }();

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

var child_process = require('child_process');
var path = require('path');
var deasync = require('deasync');
var relative = require('require-relative');
var Glob = require('./glob');
var DEFAULT_RC = require('../conf/cilintrc.js');

/**
 * Diff stdout expr
 * @type {RegExp}
 */
var DIFF_REG = /(\n|^)diff --git a\/(\S+) b\/\2[\s\S]*?\n\+\+\+[^\n]*((\n[ +\-@][^\n]*)*)/gi;

/**
 * Modified region expr
 * @type {RegExp}
 */
var MODIFY_REG = /\n@@ -(\d+),\d+ \+(\d+),\d+ @@[^\n]*((\n[ \-+][^\n]*)*)/gi;

/**
 * Get modified lines for sign file
 * @param {String} modify
 * @return {Array.<Number>}
 */
function getModifiedLines(modify) {
    var lines = [];
    var match = null;

    var _loop = function _loop() {
        var text = match[3];
        var newline = +match[2];
        text.replace(/^\n/, '').split(/\n/).forEach(function (line) {
            if (line.match(/^\+/)) {
                lines.push(newline);
            }
            if (!line.match(/^-/)) {
                newline++;
            }
        });
    };

    while (match = MODIFY_REG.exec(modify)) {
        _loop();
    }
    return lines;
}

/**
 * Get modified files from diff
 * @param {String} diff
 * @return {Object}
 */
function getModifiedFilesFromDiff(diff) {
    var files = [];
    var match = null;
    while (match = DIFF_REG.exec(diff)) {
        var filePath = match[2];
        var modify = match[3];
        var lines = getModifiedLines(modify);

        if (lines.length) {
            files.push({
                filePath: filePath,
                lines: lines
            });
        }
    }
    return files;
}

/**
 * assign lint info to files
 * @param {Array.<Object>} files
 * @param {Object} lintMap
 */
function assignLintToFiles(files, lintMap) {
    return files.map(function (file) {
        var lint = lintMap[file.fullpath] || {
            messages: []
        };
        return Object.assign({}, file, {
            // 过滤非新增行
            messages: lint.messages.filter(function (msg) {
                return file.lines.indexOf(msg.line) !== -1;
            })
        });
    });
}

/**
 * Get ESLint bin path
 * @param {String} root
 * @return {String}
 */
function getESLintPath(root) {
    var eslint = void 0;
    try {
        eslint = relative.resolve('eslint/bin/eslint', root);
    } catch (ex) {}

    if (!eslint) {
        try {
            eslint = relative.resolve('eslint/bin/eslint', __dirname);
        } catch (ex) {}
    }

    return eslint || null;
}

var Engine = function () {
    /**
     * @construtor
     * @param {Object} options 
     * @param {String} options.root project root(has a .git/.svn dir)
     * @param {String} options.cwd current working dir
     * @param {String} options.repo repo type(git|svn)
     * @param {Boolean} options.cached cached git --cached
     * @param {Object} options.rc rc rc config
     * @param {?Array.<String>} options.files lint files
     */
    function Engine(options) {
        _classCallCheck(this, Engine);

        options = Object.assign(Object.create(null), {
            repo: 'git',
            cached: false,
            cwd: process.cwd()
        }, options);

        this.options = options;

        this.initRc();
    }

    /**
     * Read `.cilintrc.js`
     */


    _createClass(Engine, [{
        key: 'initRc',
        value: function initRc() {
            var options = this.options;

            // use options's rc

            if (options.rc) {
                this.rc = options.rc;
                return;
            }

            var rc = void 0;
            try {
                rc = require(path.jion(options.root, '.cilintrc.js'));
            } catch (ex) {}

            this.rc = Object.assign({}, DEFAULT_RC, rc);
        }

        /**
         * Get modified files
         * @return {Object}
         */

    }, {
        key: 'getModifiedFiles',
        value: function getModifiedFiles() {
            var options = this.options;

            var filesOption = (options.files || []).map(function (str) {
                return '"' + str + '"';
            });

            var cmd = void 0;
            if (options.repo === 'svn') {
                cmd = 'svn diff ' + filesOption.join(' ');
            } else if (options.repo === 'git') {
                cmd = 'git diff ' + (options.cached ? '--cached' : '') + ' ' + filesOption.join(' ');
            } else {
                throw new Error('Unsupport repo type', options.repo);
            }

            var diff = child_process.execSync(cmd).toString();

            var ignoreGlob = new Glob(this.rc.ignore || []);

            return getModifiedFilesFromDiff(diff).map(function (item) {
                // filePath是相对仓库根目录的
                // fullpath绝对路径
                item.fullpath = path.resolve(options.root, item.filePath);
                // subpath相对cwd
                item.cwdpath = item.fullpath.replace(options.cwd.replace(/[\/\\]?$/, path.sep), '');
                return item;
            }).filter(function (item) {
                return !ignoreGlob(item.filePath);
            });
        }

        /**
         * Get eslint for js
         * @param {Array.<String>} files
         * @return {Object}
         */

    }, {
        key: 'getEslint',
        value: function getEslint(files) {
            var eslintPath = getESLintPath(this.options.root);

            if (!eslintPath) {
                throw new Error('Could not find eslint');
            }

            return deasync(function (done) {
                var cmd = 'node ' + eslintPath + ' -f json ' + files.map(function (str) {
                    return '"' + str + '"';
                }).join(' ');
                // eslint如果有错误child_process会exit=1, 此时如果使用execSync会抛异常
                child_process.exec(cmd, function (error, stdout) {
                    var lint = [];
                    try {
                        lint = JSON.parse(stdout.toString()) || [];
                    } catch (ex) {}
                    var ret = {};
                    lint.forEach(function (item) {
                        item.messages.forEach(function (msg) {
                            msg.isError = msg.severity > 1 || msg.fatal;
                        });

                        ret[item.filePath] = {
                            messages: item.messages
                        };
                    });
                    done(null, ret);
                });
            })();
        }

        /**
         * Get lint for files
         * @param {Array.<String>} files
         * @return {Object}
         */

    }, {
        key: 'getLintInfo',
        value: function getLintInfo(files) {
            var js = files.filter(function (item) {
                return item.match(/\.js$/);
            });
            return Object.assign.apply(Object, [js.length ? this.getEslint(js) : []]);
        }

        /**
         * Get lint results
         * @return {Array.<Object>} 
         */

    }, {
        key: 'getResults',
        value: function getResults() {
            var files = this.getModifiedFiles();

            var paths = files.map(function (file) {
                return file.cwdpath;
            });

            var lintInfo = this.getLintInfo(paths);

            var results = assignLintToFiles(files, lintInfo);

            return results;
        }
    }]);

    return Engine;
}();

module.exports = Engine;

==> cilint-0.0.12.tgz: package/lib/engine.js <==
'use strict';

var _createClass = function () { function defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } } return function (Constructor, protoProps, staticProps) { if (protoProps) defineProperties(Constructor.prototype, protoProps); if (staticProps) defineProperties(Constructor, staticProps); return Constructor; }; }();

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

var child_process = require('child_process');
var path = require('path');
var deasync = require('deasync');
var relative = require('require-relative');
var Glob = require('./glob');
var DEFAULT_RC = require('../conf/cilintrc.js');

/**
 * Diff stdout expr
 * @type {RegExp}
 */
var DIFF_REG = /(\n|^)diff --git a\/(\S+) b\/\2[\s\S]*?\n\+\+\+[^\n]*((\n[ +\-@][^\n]*)*)/gi;

/**
 * Modified region expr
 * @type {RegExp}
 */
var MODIFY_REG = /\n@@ -(\d+),\d+ \+(\d+),\d+ @@[^\n]*((\n[ \-+][^\n]*)*)/gi;

/**
 * Get modified lines for sign file
 * @param {String} modify
 * @return {Array.<Number>}
 */
function getModifiedLines(modify) {
    var lines = [];
    var match = null;

    var _loop = function _loop() {
        var text = match[3];
        var newline = +match[2];
        text.replace(/^\n/, '').split(/\n/).forEach(function (line) {
            if (line.match(/^\+/)) {
                lines.push(newline);
            }
            if (!line.match(/^-/)) {
                newline++;
            }
        });
    };

    while (match = MODIFY_REG.exec(modify)) {
        _loop();
    }
    return lines;
}

/**
 * Get modified files from diff
 * @param {String} diff
 * @return {Object}
 */
function getModifiedFilesFromDiff(diff) {
    var files = [];
    var match = null;
    while (match = DIFF_REG.exec(diff)) {
        var filePath = match[2];
        var modify = match[3];
        var lines = getModifiedLines(modify);

        if (lines.length) {
            files.push({
                filePath: filePath,
                lines: lines
            });
        }
    }
    return files;
}

/**
 * assign lint info to files
 * @param {Array.<Object>} files
 * @param {Object} lintMap
 */
function assignLintToFiles(files, lintMap) {
    return files.map(function (file) {
        var lint = lintMap[file.fullpath] || {
            messages: []
        };
        return Object.assign({}, file, {
            // 过滤非新增行
            messages: lint.messages.filter(function (msg) {
                return file.lines.indexOf(msg.line) !== -1;
            })
        });
    });
}

/**
 * Get ESLint bin path
 * @param {String} root
 * @return {String}
 */
function getESLintPath(root) {
    var eslint = void 0;
    try {
        eslint = relative.resolve('eslint/bin/eslint', root);
    } catch (ex) {}

    if (!eslint) {
        try {
            eslint = relative.resolve('eslint/bin/eslint', __dirname);
        } catch (ex) {}
    }

    return eslint || null;
}

var Engine = function () {
    /**
     * @construtor
     * @param {Object} options 
     * @param {String} options.root project root(has a .git/.svn dir)
     * @param {String} options.cwd current working dir
     * @param {String} options.repo repo type(git|svn)
     * @param {Boolean} options.cached cached git --cached
     * @param {Object} options.rc rc rc config
     * @param {?Array.<String>} options.files lint files
     */
    function Engine(options) {
        _classCallCheck(this, Engine);

        options = Object.assign(Object.create(null), {
            repo: 'git',
            cached: false,
            cwd: process.cwd()
        }, options);

        this.options = options;

        this.initRc();
    }

    /**
     * Read `.cilintrc.js`
     */


    _createClass(Engine, [{
        key: 'initRc',
        value: function initRc() {
            var options = this.options;

            // use options's rc

            if (options.rc) {
                this.rc = options.rc;
                return;
            }

            var rc = void 0;
            try {
                rc = require(path.jion(options.root, '.cilintrc.js'));
            } catch (ex) {}

            this.rc = Object.assign({}, DEFAULT_RC, rc);
        }

        /**
         * Get modified files
         * @return {Object}
         */

    }, {
        key: 'getModifiedFiles',
        value: function getModifiedFiles() {
            var options = this.options;

            var filesOption = (options.files || []).map(function (str) {
                return '"' + str + '"';
            });

            var cmd = void 0;
            if (options.repo === 'svn') {
                cmd = 'svn diff ' + filesOption.join(' ');
            } else if (options.repo === 'git') {
                cmd = 'git diff ' + (options.cached ? '--cached' : '') + ' ' + filesOption.join(' ');
            } else {
                throw new Error('Unsupport repo type', options.repo);
            }

            var diff = child_process.execSync(cmd).toString();

            var ignoreGlob = new Glob(this.rc.ignore || []);

            return getModifiedFilesFromDiff(diff).map(function (item) {
                // filePath是相对仓库根目录的
                // fullpath绝对路径
                item.fullpath = path.resolve(options.root, item.filePath);
                // subpath相对cwd
                item.cwdpath = item.fullpath.replace(options.cwd.replace(/[\/\\]?$/, path.sep), '');
                return item;
            }).filter(function (item) {
                return !ignoreGlob(item.filePath);
            });
        }

        /**
         * Get eslint for js
         * @param {Array.<String>} files
         * @return {Object}
         */

    }, {
        key: 'getEslint',
        value: function getEslint(files) {
            var eslintPath = getESLintPath(this.options.root);

            if (!eslintPath) {
                throw new Error('Could not find eslint');
            }

            return deasync(function (done) {
                var cmd = 'node ' + eslintPath + ' -f json ' + files.map(function (str) {
                    return '"' + str + '"';
                }).join(' ');
                // eslint如果有错误child_process会exit=1, 此时如果使用execSync会抛异常
                child_process.exec(cmd, function (error, stdout) {
                    var lint = [];
                    var stdoutStr = stdout.toString() || '';
                    try {
                        lint = JSON.parse(stdoutStr) || [];
                    } catch (ex) {
                        if (stdoutStr.length > 10) {
                            var message = '\n\nESLint path: ' + eslintPath;

                            message += stdoutStr.replace(/\nOops![^\n]*/, '');

                            throw new Error(message);
                        }
                    }
                    var ret = {};
                    lint.forEach(function (item) {
                        item.messages.forEach(function (msg) {
                            msg.isError = msg.severity > 1 || msg.fatal;
                        });

                        ret[item.filePath] = {
                            messages: item.messages
                        };
                    });
                    done(null, ret);
                });
            })();
        }

        /**
         * Get lint for files
         * @param {Array.<String>} files
         * @return {Object}
         */

    }, {
        key: 'getLintInfo',
        value: function getLintInfo(files) {
            var js = files.filter(function (item) {
                return item.match(/\.js$/);
            });
            return Object.assign.apply(Object, [js.length ? this.getEslint(js) : []]);
        }

        /**
         * Get lint results
         * @return {Array.<Object>} 
         */

    }, {
        key: 'getResults',
        value: function getResults() {
            var files = this.getModifiedFiles();

            var paths = files.map(function (file) {
                return file.cwdpath;
            });

            var lintInfo = this.getLintInfo(paths);

            var results = assignLintToFiles(files, lintInfo);

            return results;
        }
    }]);

    return Engine;
}();

module.exports = Engine;
